IQM client
##########

:Release: |release|
:Date: |today|
:Source Code: `<https://github.com/iqm-finland/iqm-client>`_

Client-side library for connecting to an `IQM <https://meetiqm.com/>`_ quantum computer.

Contents
========

.. toctree::
   :maxdepth: 2

   readme
   API
   license
   authors
   changelog
   json_schemas


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
